[PATCH 8/12] gdium uses different freq of mclk&m1xclk of sm501

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Gdium uses different freq of mclk&m1xclk of sm501. This seems a dirty
hack. Maybe we need a configuration option for changing the freq of
these clocks.

Signed-off-by: yajin <yajin@xxxxxxxxxxxxx>
---
 drivers/mfd/sm501.c |    9 +++++++--
 1 files changed, 7 insertions(+), 2 deletions(-)

diff --git a/drivers/mfd/sm501.c b/drivers/mfd/sm501.c
index ce5dfce..5e55cbd 100644
--- a/drivers/mfd/sm501.c
+++ b/drivers/mfd/sm501.c
@@ -1606,10 +1606,15 @@ static struct sm501_initdata sm501_pci_initdata = {
 	.devices	= SM501_USE_ALL,

 	/* Errata AB-3 says that 72MHz is the fastest available
-	 * for 33MHZ PCI with proper bus-mastering operation */
-
+	 * for 33MHZ PCI with proper bus-mastering operation
+	 * For gdium, it works under 84&112M clock freq.*/
+#ifdef CONFIG_DEXXON_GDIUM
+	.mclk		= 84 * MHZ,
+	.m1xclk		= 112 * MHZ,
+#else
 	.mclk		= 72 * MHZ,
 	.m1xclk		= 144 * MHZ,
+#endif
 };

 static struct sm501_platdata_fbsub sm501_pdata_fbsub = {
-- 
1.5.6.5


[Index of Archives]     [Linux MIPS Home]     [LKML Archive]     [Linux ARM Kernel]     [Linux ARM]     [Linux]     [Git]     [Yosemite News]     [Linux SCSI]     [Linux Hams]

  Powered by Linux